import type { ComponentProps } from 'react';
import { Button } from '../ui/button';
export type ActionsProps = ComponentProps<'div'>;
export declare const Actions: ({ className, children, ...props }: ActionsProps) => import("react").JSX.Element;
export type ActionProps = ComponentProps<typeof Button> & {
    tooltip?: string;
    label?: string;
};
export declare const Action: ({ tooltip, children, label, className, variant, size, ...props }: ActionProps) => import("react").JSX.Element;
//# sourceMappingURL=actions.d.ts.map