import type { ConnectionStatus } from '../../types/config';
export interface HeaderProps {
    className?: string;
    title?: string;
    showSettings?: boolean;
}
export declare function Header({ className, title, showSettings }: HeaderProps): import("react").JSX.Element;
export declare function StatusIndicator({ status }: {
    status: ConnectionStatus;
}): import("react").JSX.Element | null;
export default Header;
//# sourceMappingURL=header.d.ts.map