export function createWorkbench(config = { route: '/workbench', headers: {} }) {
    const finalConfig = {
        route: config.route,
        headers: config.headers,
    };
    return {
        config: finalConfig,
    };
}
//# sourceMappingURL=workbench.js.map