import type { JSONSchema7 } from 'ai';
import React from 'react';
interface JsonEditorProps {
    'aria-invalid'?: boolean;
    className?: string;
    onChange: (value: string) => void;
    onSubmit: () => void;
    onValidationChange?: (hasErrors: boolean) => void;
    schema?: JSONSchema7;
    schemaUri?: string;
    value: string;
}
export declare function JsonEditor({ 'aria-invalid': ariaInvalid, className, onChange, onSubmit, onValidationChange, schema, schemaUri, value, }: JsonEditorProps): React.JSX.Element;
export {};
//# sourceMappingURL=json-editor.d.ts.map