export interface ChatProps {
    className?: string;
    emptyState?: React.ReactNode;
    onSchemaToggle?: () => void;
    onSessionOpen?: (sessionId: string) => void;
    schemaOpen?: boolean;
}
export declare function Chat({ className, emptyState, onSchemaToggle, onSessionOpen, schemaOpen, }: ChatProps): import("react").JSX.Element;
export default Chat;
//# sourceMappingURL=chat.d.ts.map