export interface SchemaProps {
    onOpenChange?: (open: boolean) => void;
}
export declare function Schema({ onOpenChange }: SchemaProps): import("react").JSX.Element;
export default Schema;
//# sourceMappingURL=schema.d.ts.map